.. include:: ../roles.rst

.. _api_reference:

API Library Reference
=====================

The current models are implemented under :py:mod:`ormm.mathprog`, containing
factory methods to implement problem classes and other useful functions for
solution analysis.

.. currentmodule:: ormm.mathprog

.. autosummary::

   blending
   resource_allocation
   print_sol
   sensitivity_analysis


API Component Documentation
~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autofunction:: blending

.. autofunction:: resource_allocation

.. autofunction:: print_sol

.. autofunction:: sensitivity_analysis